pub async fn account_list_identities(
configuration: &Configuration,
queries: Option<&str>,
) -> Result<IdentityList, Error<AccountListIdentitiesError>>Expand description
Get the list of identities for the currently logged in user.
pub async fn account_list_identities(
configuration: &Configuration,
queries: Option<&str>,
) -> Result<IdentityList, Error<AccountListIdentitiesError>>Get the list of identities for the currently logged in user.