account_update_phone_verification

Function account_update_phone_verification 

pub async fn account_update_phone_verification(
    configuration: &Configuration,
    payload: Option<AccountUpdateVerificationRequest>,
) -> Result<Token, Error<AccountUpdatePhoneVerificationError>>
Use this endpoint to complete the user phone verification process. Use the userId and secret that were sent to your user’s phone number to verify the user email ownership. If confirmed this route will return a 200 status code.