databases_create_collection

Function databases_create_collection 

pub async fn databases_create_collection(
    configuration: &Configuration,
    database_id: &str,
    payload: Option<DatabasesCreateCollectionRequest>,
) -> Result<Collection, Error<DatabasesCreateCollectionError>>
Create a new Collection. Before using this route, you should create a new database resource using either a server integration API or directly from your database console.