databases_list_collections

Function databases_list_collections 

pub async fn databases_list_collections(
    configuration: &Configuration,
    database_id: &str,
    queries: Option<Vec<String>>,
    search: Option<&str>,
) -> Result<CollectionList, Error<DatabasesListCollectionsError>>
Get a list of all collections that belong to the provided databaseId. You can use the search parameter to filter your results.