teams_get_membership

Function teams_get_membership 

pub async fn teams_get_membership(
    configuration: &Configuration,
    team_id: &str,
    membership_id: &str,
) -> Result<Membership, Error<TeamsGetMembershipError>>
Get a team member by the membership unique id. All team members have read access for this resource.