Module users_api

Module users_api 

Enums

UsersCreateArgon2UserError
struct for typed errors of method users_create_argon2_user
UsersCreateBcryptUserError
struct for typed errors of method users_create_bcrypt_user
UsersCreateError
struct for typed errors of method users_create
UsersCreateMd5UserError
struct for typed errors of method users_create_md5_user
UsersCreatePhPassUserError
struct for typed errors of method users_create_ph_pass_user
UsersCreateScryptModifiedUserError
struct for typed errors of method users_create_scrypt_modified_user
UsersCreateScryptUserError
struct for typed errors of method users_create_scrypt_user
UsersCreateShaUserError
struct for typed errors of method users_create_sha_user
UsersDeleteError
struct for typed errors of method users_delete
UsersDeleteIdentityError
struct for typed errors of method users_delete_identity
UsersDeleteSessionError
struct for typed errors of method users_delete_session
UsersDeleteSessionsError
struct for typed errors of method users_delete_sessions
UsersGetError
struct for typed errors of method users_get
UsersGetPrefsError
struct for typed errors of method users_get_prefs
UsersListError
struct for typed errors of method users_list
UsersListIdentitiesError
struct for typed errors of method users_list_identities
UsersListLogsError
struct for typed errors of method users_list_logs
UsersListMembershipsError
struct for typed errors of method users_list_memberships
UsersListSessionsError
struct for typed errors of method users_list_sessions
UsersUpdateEmailError
struct for typed errors of method users_update_email
UsersUpdateEmailVerificationError
struct for typed errors of method users_update_email_verification
UsersUpdateLabelsError
struct for typed errors of method users_update_labels
UsersUpdateNameError
struct for typed errors of method users_update_name
UsersUpdatePasswordError
struct for typed errors of method users_update_password
UsersUpdatePhoneError
struct for typed errors of method users_update_phone
UsersUpdatePhoneVerificationError
struct for typed errors of method users_update_phone_verification
UsersUpdatePrefsError
struct for typed errors of method users_update_prefs
UsersUpdateStatusError
struct for typed errors of method users_update_status

Functions

users_create
Create a new user.
users_create_argon2_user
Create a new user. Password provided must be hashed with the Argon2 algorithm. Use the POST /users endpoint to create users with a plain text password.
users_create_bcrypt_user
Create a new user. Password provided must be hashed with the Bcrypt algorithm. Use the POST /users endpoint to create users with a plain text password.
users_create_md5_user
Create a new user. Password provided must be hashed with the MD5 algorithm. Use the POST /users endpoint to create users with a plain text password.
users_create_ph_pass_user
Create a new user. Password provided must be hashed with the PHPass algorithm. Use the POST /users endpoint to create users with a plain text password.
users_create_scrypt_modified_user
Create a new user. Password provided must be hashed with the Scrypt Modified algorithm. Use the POST /users endpoint to create users with a plain text password.
users_create_scrypt_user
Create a new user. Password provided must be hashed with the Scrypt algorithm. Use the POST /users endpoint to create users with a plain text password.
users_create_sha_user
Create a new user. Password provided must be hashed with the SHA algorithm. Use the POST /users endpoint to create users with a plain text password.
users_delete
Delete a user by its unique ID, thereby releasing it’s ID. Since ID is released and can be reused, all user-related resources like documents or storage files should be deleted before user deletion. If you want to keep ID reserved, use the updateStatus endpoint instead.
users_delete_identity
Delete an identity by its unique ID.
users_delete_session
Delete a user sessions by its unique ID.
users_delete_sessions
Delete all user’s sessions by using the user’s unique ID.
users_get
Get a user by its unique ID.
users_get_prefs
Get the user preferences by its unique ID.
users_list
Get a list of all the project’s users. You can use the query params to filter your results.
users_list_identities
Get identities for all users.
users_list_logs
Get the user activity logs list by its unique ID.
users_list_memberships
Get the user membership list by its unique ID.
users_list_sessions
Get the user sessions list by its unique ID.
users_update_email
Update the user email by its unique ID.
users_update_email_verification
Update the user email verification status by its unique ID.
users_update_labels
Update the user labels by its unique ID. Labels can be used to grant access to resources. While teams are a way for user’s to share access to a resource, labels can be defined by the developer to grant access without an invitation. See the Permissions docs for more info.
users_update_name
Update the user name by its unique ID.
users_update_password
Update the user password by its unique ID.
users_update_phone
Update the user phone by its unique ID.
users_update_phone_verification
Update the user phone verification status by its unique ID.
users_update_prefs
Update the user preferences by its unique ID. The object you pass is stored as is, and replaces any previous value. The maximum allowed prefs size is 64kB and throws error if exceeded.
users_update_status
Update the user status by its unique ID. Use this endpoint as an alternative to deleting a user if you want to keep user’s ID reserved.