StorageUpdateBucketRequest

Struct StorageUpdateBucketRequest 

pub struct StorageUpdateBucketRequest {
    pub name: String,
    pub permissions: Option<Vec<String>>,
    pub file_security: Option<bool>,
    pub enabled: Option<bool>,
    pub maximum_file_size: Option<i32>,
    pub allowed_file_extensions: Option<Vec<String>>,
    pub compression: Option<Compression>,
    pub encryption: Option<bool>,
    pub antivirus: Option<bool>,
}

Fields

name: String

Bucket name

permissions: Option<Vec<String>>

An array of permission strings. By default, the current permissions are inherited. Learn more about permissions.

file_security: Option<bool>

Enables configuring permissions for individual file. A user needs one of file or bucket level permissions to access a file. Learn more about permissions.

enabled: Option<bool>

Is bucket enabled? When set to ‘disabled’, users cannot access the files in this bucket but Server SDKs with and API key can still access the bucket. No files are lost when this is toggled.

maximum_file_size: Option<i32>

Maximum file size allowed in bytes. Maximum allowed value is 30MB.

allowed_file_extensions: Option<Vec<String>>

Allowed file extensions. Maximum of 100 extensions are allowed, each 64 characters long.

compression: Option<Compression>

Compression algorithm choosen for compression. Can be one of none, gzip, or zstd, For file size above 20MB compression is skipped even if it’s enabled

encryption: Option<bool>

Is encryption enabled? For file size above 20MB encryption is skipped even if it’s enabled

antivirus: Option<bool>

Is virus scanning enabled? For file size above 20MB AntiVirus scanning is skipped even if it’s enabled

Implementations