pub async fn databases_list_collections(
configuration: &Configuration,
database_id: &str,
queries: Option<Vec<String>>,
search: Option<&str>,
) -> Result<CollectionList, Error<DatabasesListCollectionsError>>Expand description
Get a list of all collections that belong to the provided databaseId. You can use the search parameter to filter your results.