pub async fn teams_get_membership(
configuration: &Configuration,
team_id: &str,
membership_id: &str,
) -> Result<Membership, Error<TeamsGetMembershipError>>Expand description
Get a team member by the membership unique id. All team members have read access for this resource.