pub async fn teams_list(
configuration: &Configuration,
queries: Option<Vec<String>>,
search: Option<&str>,
) -> Result<TeamList, Error<TeamsListError>>Expand description
Get a list of all the teams in which the current user is a member. You can use the parameters to filter your results.