Enums
- Users
Create Argon2 User Error - struct for typed errors of method
users_create_argon2_user - Users
Create Bcrypt User Error - struct for typed errors of method
users_create_bcrypt_user - Users
Create Error - struct for typed errors of method
users_create - Users
Create Md5User Error - struct for typed errors of method
users_create_md5_user - Users
Create PhPass User Error - struct for typed errors of method
users_create_ph_pass_user - Users
Create Scrypt Modified User Error - struct for typed errors of method
users_create_scrypt_modified_user - Users
Create Scrypt User Error - struct for typed errors of method
users_create_scrypt_user - Users
Create ShaUser Error - struct for typed errors of method
users_create_sha_user - Users
Delete Error - struct for typed errors of method
users_delete - Users
Delete Identity Error - struct for typed errors of method
users_delete_identity - Users
Delete Session Error - struct for typed errors of method
users_delete_session - Users
Delete Sessions Error - struct for typed errors of method
users_delete_sessions - Users
GetError - struct for typed errors of method
users_get - Users
GetPrefs Error - struct for typed errors of method
users_get_prefs - Users
List Error - struct for typed errors of method
users_list - Users
List Identities Error - struct for typed errors of method
users_list_identities - Users
List Logs Error - struct for typed errors of method
users_list_logs - Users
List Memberships Error - struct for typed errors of method
users_list_memberships - Users
List Sessions Error - struct for typed errors of method
users_list_sessions - Users
Update Email Error - struct for typed errors of method
users_update_email - Users
Update Email Verification Error - struct for typed errors of method
users_update_email_verification - Users
Update Labels Error - struct for typed errors of method
users_update_labels - Users
Update Name Error - struct for typed errors of method
users_update_name - Users
Update Password Error - struct for typed errors of method
users_update_password - Users
Update Phone Error - struct for typed errors of method
users_update_phone - Users
Update Phone Verification Error - struct for typed errors of method
users_update_phone_verification - Users
Update Prefs Error - struct for typed errors of method
users_update_prefs - Users
Update Status Error - struct for typed errors of method
users_update_status
Functions
- users_
create - Create a new user.
- users_
create_ argon2_ user - Create a new user. Password provided must be hashed with the Argon2 algorithm. Use the POST /users endpoint to create users with a plain text password.
- users_
create_ bcrypt_ user - Create a new user. Password provided must be hashed with the Bcrypt algorithm. Use the POST /users endpoint to create users with a plain text password.
- users_
create_ md5_ user - Create a new user. Password provided must be hashed with the MD5 algorithm. Use the POST /users endpoint to create users with a plain text password.
- users_
create_ ph_ pass_ user - Create a new user. Password provided must be hashed with the PHPass algorithm. Use the POST /users endpoint to create users with a plain text password.
- users_
create_ scrypt_ modified_ user - Create a new user. Password provided must be hashed with the Scrypt Modified algorithm. Use the POST /users endpoint to create users with a plain text password.
- users_
create_ scrypt_ user - Create a new user. Password provided must be hashed with the Scrypt algorithm. Use the POST /users endpoint to create users with a plain text password.
- users_
create_ sha_ user - Create a new user. Password provided must be hashed with the SHA algorithm. Use the POST /users endpoint to create users with a plain text password.
- users_
delete - Delete a user by its unique ID, thereby releasing it’s ID. Since ID is released and can be reused, all user-related resources like documents or storage files should be deleted before user deletion. If you want to keep ID reserved, use the updateStatus endpoint instead.
- users_
delete_ identity - Delete an identity by its unique ID.
- users_
delete_ session - Delete a user sessions by its unique ID.
- users_
delete_ sessions - Delete all user’s sessions by using the user’s unique ID.
- users_
get - Get a user by its unique ID.
- users_
get_ prefs - Get the user preferences by its unique ID.
- users_
list - Get a list of all the project’s users. You can use the query params to filter your results.
- users_
list_ identities - Get identities for all users.
- users_
list_ logs - Get the user activity logs list by its unique ID.
- users_
list_ memberships - Get the user membership list by its unique ID.
- users_
list_ sessions - Get the user sessions list by its unique ID.
- users_
update_ email - Update the user email by its unique ID.
- users_
update_ email_ verification - Update the user email verification status by its unique ID.
- users_
update_ labels - Update the user labels by its unique ID. Labels can be used to grant access to resources. While teams are a way for user’s to share access to a resource, labels can be defined by the developer to grant access without an invitation. See the Permissions docs for more info.
- users_
update_ name - Update the user name by its unique ID.
- users_
update_ password - Update the user password by its unique ID.
- users_
update_ phone - Update the user phone by its unique ID.
- users_
update_ phone_ verification - Update the user phone verification status by its unique ID.
- users_
update_ prefs - Update the user preferences by its unique ID. The object you pass is stored as is, and replaces any previous value. The maximum allowed prefs size is 64kB and throws error if exceeded.
- users_
update_ status - Update the user status by its unique ID. Use this endpoint as an alternative to deleting a user if you want to keep user’s ID reserved.